﻿#include "stdafx.h"
#include "AboutWnd.hpp"
#include "NeMessengerDlg.h"
#include "DuiDefine.h"
#include "..\..\DuiLib\Utils\WinImplBase.h"



DUI_BEGIN_MESSAGE_MAP(CAboutWnd, WindowImplBase, FALSE)
    DUI_ON_MSGTYPE(DUI_MSGTYPE_WINDOWINIT, OnPrepare)
    DUI_ON_MSGTYPE(DUI_MSGTYPE_CLICK, NotifyCtrlClick)     //kClick
    DUI_ON_MSGTYPE(DUI_MSGTYPE_SETFOCUS, OnNotifySetFocus)
    DUI_ON_MSGTYPE(DUI_MSGTYPE_KILLFOCUS, OnNotifyKillFocus)
DUI_END_MESSAGE_MAP()


CAboutWnd::CAboutWnd()
{
	m_bClosing = FALSE;
}

CAboutWnd::~CAboutWnd()
{

}

void CAboutWnd::InitWindow()
{
	
}

LPCTSTR CAboutWnd::GetWindowClassName() const
{
	return _T("AboutWindow");
}

void CAboutWnd::OnFinalMessage(HWND hWnd)
{
	WindowImplBase::OnFinalMessage(hWnd);
	delete this;
}

void CAboutWnd::NotifyCtrlClick(TNotifyUI& msg)
{
	if (_tcsicmp(msg.pSender->GetName(), kCloseButtonControlName) == 0)
	{
		Close();
	}
}

LRESULT CAboutWnd::OnLButtonDown(UINT uMsg, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
{
	POINT pt = { GET_X_LPARAM(lParam), GET_Y_LPARAM(lParam) };
	CButtonUI* pBtnClose =  static_cast<CButtonUI*>(m_PaintManager.FindControl(kCloseButtonControlName));
	CHorizontalLayoutUI* pTitle =  static_cast<CHorizontalLayoutUI*>(m_PaintManager.FindControl(kPopupTitle));
	if (pBtnClose != NULL && pTitle != NULL)
	{
		CRect rcText = pBtnClose->GetPos();
		if (rcText.PtInRect(pt))
		{
			CString strImage = GetAppDUIImgDir() + _T("\\img_alarm_popup_bg_top_off.png");
			pTitle->SetBkImage(strImage);
		}
	}
	bHandled = FALSE;
	return 0;
}

LRESULT CAboutWnd::OnLButtonUp(UINT uMsg, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
{
	//POINT pt = { GET_X_LPARAM(lParam), GET_Y_LPARAM(lParam) };
	CHorizontalLayoutUI* pTitle =  static_cast<CHorizontalLayoutUI*>(m_PaintManager.FindControl(kPopupTitle));
	if (pTitle != NULL)
	{
		CString strImage = GetAppDUIImgDir() + _T("\\img_alarm_popup_bg_top_on.png");
		pTitle->SetBkImage(strImage);
	}
	bHandled = FALSE;
	return 0;
}

void CAboutWnd::OnNotifySetFocus(TNotifyUI& msg)
{
    
}

void CAboutWnd::OnNotifyKillFocus(TNotifyUI& msg)
{
    
}

void CAboutWnd::CloseAboutWnd()
{
	m_bClosing = TRUE;
	Close();
}

void CAboutWnd::OnPrepare(TNotifyUI& msg)
{
	LoadVersionInfo();
	CLabelUI* pLabVersion = static_cast<CLabelUI*>(m_PaintManager.FindControl(_T("lab_txt_version")));
	if (pLabVersion != NULL)
	{
		pLabVersion->SetText(m_strUpdateVersion);
	}
}

CDuiString CAboutWnd::GetSkinFile()
{
	return _T("about_wnd.xml");
}

CDuiString CAboutWnd::GetSkinFolder()
{
	return _T("skin\\nTalkRes");
}

LRESULT CAboutWnd::OnKillFocus(UINT uMsg, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
{
	return 0;
}

LRESULT CAboutWnd::OnNcHitTest(UINT uMsg, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
{
	int ret = __super::OnNcHitTest(uMsg, wParam, lParam, bHandled);
	if (ret != HTCAPTION)
	{
		ret = HTCLIENT;
	}
	return ret;
}

void CAboutWnd::LoadVersionInfo()
{
	CString strVersion = _T("");
	CString strLastUpdate = _T("");
	CString strFormat;
	HRSRC hRsrc = FindResource(NULL, MAKEINTRESOURCE(VS_VERSION_INFO), RT_VERSION);
	if (hRsrc != NULL)
	{
		HGLOBAL hGlobalMemory = LoadResource(NULL, hRsrc);
		if (hGlobalMemory != NULL)
		{
			CString rVersion;
			CString rSpecialBuild;
			LPVOID pVersionResouece = LockResource(hGlobalMemory);
			LPVOID pVersion = NULL;
			LPVOID pLastUpdate = NULL;
			DWORD uLength,langD;
			BOOL retVal;
			retVal = VerQueryValue(pVersionResouece, _T("\\VarFileInfo\\Translation"), (LPVOID*)&pVersion, (UINT*)&uLength);
			if (retVal && uLength == 4) 
			{
				memcpy(&langD,pVersion,4); 
				rVersion.Format(_T("\\StringFileInfo\\%02X%02X%02X%02X\\ProductVersion"),
					(langD & 0xff00)>>8,langD & 0xff,(langD & 0xff000000)>>24, 
					(langD & 0xff0000)>>16);
				rSpecialBuild.Format(_T("\\StringFileInfo\\%02X%02X%02X%02X\\SpecialBuild"),
					(langD & 0xff00)>>8,langD & 0xff,(langD & 0xff000000)>>24, 
					(langD & 0xff0000)>>16);
			}
			else
			{
				rVersion.Format(_T("\\StringFileInfo\\%04X04B0\\ProductVersion"), GetUserDefaultLangID());
				rSpecialBuild.Format(_T("\\StringFileInfo\\%04X04B0\\SpecialBuild"), GetUserDefaultLangID());
			}

			if( VerQueryValue(pVersionResouece, (LPCTSTR)rVersion, (LPVOID*)&pVersion, (UINT *)&uLength) != 0 )
			{
				strVersion.Format(_T("%s"), pVersion);
			}

			if( VerQueryValue(pVersionResouece, (LPCTSTR)rSpecialBuild, (LPVOID*)&pLastUpdate, (UINT *)&uLength) != 0 )
			{
				strLastUpdate.Format(_T("%s"), pLastUpdate);
			}
		}
		FreeResource(hGlobalMemory);
	}

	strFormat.LoadString(IDS_ABOUT_VERSION);
	m_strUpdateVersion.Format(strFormat, strVersion);

	strFormat.LoadString(IDS_ABOUT_DATE);
	m_strUpdateDate.Format(strFormat, strLastUpdate);
}







